@@ -207,9 +207,6 @@ gs_moderate_page_get_unvoted_reviews_cb (GObject *source_object,
 		app = gs_app_list_index (list, i);
 		gs_moderate_page_add_app (self, app);
 	}
-
-	/* seems a good place */
-	gs_shell_profile_dump (self->shell);
 }
 
 static void
